@@ -18,16 +18,24 @@ __correspondence_email__ = 'alexander.juestel@rwth-aachen.de'
 
 __affiliations__ = 'CGRE - RWTH Aachen University'
 
-__version_date__ = '2021-03-14'
+__version_date__ = '2021-03-17'
 
-__version__ = '0.1.11'
+__version__ = '0.1.12'
 
-__changelog__ = """What is new in version 0.1.11:
-- Fix Notebooks
+__changelog__ = """What is new in version 0.1.12:
+- Removing more dependencies
+- Minor bug fixes
 
 """
 
-__changelogs__ = {'0.1.10': """What is new in version 0.1.10:
+__changelogs__ = {'0.1.11': """What is new in version 0.1.11:
+- Fixing Notebooks
+- Making tests ready for pooch
+- Making example ready for pooch
+- Removing dependencies from package
+""",
+
+                  '0.1.10': """What is new in version 0.1.10:
 - Adding Pooch support for notebooks
 - Removing dependencies from package and making them optional
 """,
