@@ -1,11 +1,11 @@
 """
-Contributors: Alexander Jüstel, Arthur Endlein Correia, Florian Wellmann
+Contributors: Alexander Jüstel, Arthur Endlein Correia, Florian Wellmann, Marius Pischke
 
-GemGIS is a Python-based, open-source geographic information processing library.
-It is capable of preprocessing spatial data such as vector data (shape files, geojson files, geopackages),
-raster data, data obtained from WMS services or XML/KML files.
-Preprocessed data can be stored in a dedicated Data Class to be passed to the geomodeling package GemPy
-in order to accelerate to model building process.
+GemGIS is a Python-based, open-source spatial data processing library.
+It is capable of preprocessing spatial data such as vector data
+raster data, data obtained from online services and many more data formats.
+GemGIS wraps and extends the functionality of packages known to the geo-community
+such as GeoPandas, Rasterio, OWSLib, Shapely, PyVista, Pandas, and NumPy.
 
 GemGIS is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -26,24 +26,6 @@ from typing import Union, List
 import geopandas as gpd
 
 
-# Trying to import owslib but returning error if owslib is not installed
-try:
-    import owslib
-    from owslib import util
-    from owslib.wms import WebMapService
-    from owslib.wfs import WebFeatureService
-    from owslib.wcs import WebCoverageService
-    __all__ = [util]
-except ModuleNotFoundError:
-    pass
-    #raise ModuleNotFoundError('owslib package is not installed. Use pip install owslib to install the latest version')
-
-# Trying to import requests but returning error if requests is not installed
-try:
-    import requests
-except ModuleNotFoundError:
-    raise ModuleNotFoundError('requests package is not installed. Use pip install requests to install the latest version')
-
 # Working with Online Services
 ##############################
 
@@ -51,7 +33,7 @@ except ModuleNotFoundError:
 ###############################
 
 
-def load_wms(url: str) -> owslib.wms.WebMapService:
+def load_wms(url: str):  # -> owslib.wms.WebMapService:
     """Loading a WMS Service by URL
 
     Parameters
@@ -83,6 +65,20 @@ def load_wms(url: str) -> owslib.wms.WebMapService:
         load_as_array : Load Map as array from WMS Service
 
     """
+    # Trying to import owslib but returning error if owslib is not installed
+    try:
+        import owslib
+        from owslib.wms import WebMapService
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'owslib package is not installed. Use pip install owslib to install the latest version')
+
+    # Trying to import requests but returning error if requests is not installed
+    try:
+        import requests
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'requests package is not installed. Use pip install requests to install the latest version')
 
     # Checking if url is of type string
     if not isinstance(url, str):
@@ -109,7 +105,7 @@ def load_as_map(url: str,
                 save_image: bool = False,
                 path: str = None,
                 overwrite_file: bool = False,
-                create_directory: bool = False) -> owslib.util.ResponseWrapper:
+                create_directory: bool = False):  # -> owslib.util.ResponseWrapper:
     """Loading a portion of a WMS as array
 
     Parameters
@@ -179,6 +175,18 @@ def load_as_map(url: str,
 
     """
 
+    # Trying to import owslib but returning error if owslib is not installed
+    try:
+        import owslib
+        from owslib import util
+        from owslib.wms import WebMapService
+        from owslib.wfs import WebFeatureService
+        from owslib.wcs import WebCoverageService
+        __all__ = [util]
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'owslib package is not installed. Use pip install owslib to install the latest version')
+
     # Checking if the url is of type string
     if not isinstance(url, str):
         raise TypeError('URL must be of type string')
@@ -360,6 +368,18 @@ def load_as_array(url: str,
 
     """
 
+    # Trying to import owslib but returning error if owslib is not installed
+    try:
+        import owslib
+        from owslib import util
+        from owslib.wms import WebMapService
+        from owslib.wfs import WebFeatureService
+        from owslib.wcs import WebCoverageService
+        __all__ = [util]
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'owslib package is not installed. Use pip install owslib to install the latest version')
+
     # Trying to import matplotlib but returning error if matplotlib is not installed
     try:
         import matplotlib.pyplot as plt
@@ -461,7 +481,7 @@ def load_as_array(url: str,
 ###################################
 
 
-def load_wfs(url: str) -> owslib.wfs.WebFeatureService:
+def load_wfs(url: str):  # -> owslib.wfs.WebFeatureService:
     """Loading an WMS Service by URL
 
     Parameters
@@ -492,6 +512,25 @@ def load_wfs(url: str) -> owslib.wfs.WebFeatureService:
 
     """
 
+    # Trying to import owslib but returning error if owslib is not installed
+    try:
+        import owslib
+        from owslib import util
+        from owslib.wms import WebMapService
+        from owslib.wfs import WebFeatureService
+        from owslib.wcs import WebCoverageService
+        __all__ = [util]
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'owslib package is not installed. Use pip install owslib to install the latest version')
+
+    # Trying to import requests but returning error if requests is not installed
+    try:
+        import requests
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'requests package is not installed. Use pip install requests to install the latest version')
+
     # Checking if url is of type string
     if not isinstance(url, str):
         raise TypeError('URL must be of type string')
@@ -548,6 +587,25 @@ def load_as_gpd(url: str,
 
     """
 
+    # Trying to import owslib but returning error if owslib is not installed
+    try:
+        import owslib
+        from owslib import util
+        from owslib.wms import WebMapService
+        from owslib.wfs import WebFeatureService
+        from owslib.wcs import WebCoverageService
+        __all__ = [util]
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'owslib package is not installed. Use pip install owslib to install the latest version')
+
+    # Trying to import requests but returning error if requests is not installed
+    try:
+        import requests
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'requests package is not installed. Use pip install requests to install the latest version')
+
     # Checking that the url is of type string
     if not isinstance(url, str):
         raise TypeError('URL must be of type string')
@@ -591,7 +649,7 @@ def load_as_gpd(url: str,
 ####################################
 
 
-def load_wcs(url: str) -> owslib.wcs.WebCoverageService:
+def load_wcs(url: str):  # -> owslib.wcs.WebCoverageService:
     """Loading Web Coverage Service
 
     Parameters
@@ -624,6 +682,18 @@ def load_wcs(url: str) -> owslib.wcs.WebCoverageService:
 
     """
 
+    # Trying to import owslib but returning error if owslib is not installed
+    try:
+        import owslib
+        from owslib import util
+        from owslib.wms import WebMapService
+        from owslib.wfs import WebFeatureService
+        from owslib.wcs import WebCoverageService
+        __all__ = [util]
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'owslib package is not installed. Use pip install owslib to install the latest version')
+
     # Checking if URL is of type string
     if not isinstance(url, str):
         raise TypeError('URL must be of type string')
@@ -691,6 +761,18 @@ def create_request(wcs_url: str,
 
     """
 
+    # Trying to import owslib but returning error if owslib is not installed
+    try:
+        import owslib
+        from owslib import util
+        from owslib.wms import WebMapService
+        from owslib.wfs import WebFeatureService
+        from owslib.wcs import WebCoverageService
+        __all__ = [util]
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'owslib package is not installed. Use pip install owslib to install the latest version')
+
     # Checking that the URL is of type string
     if not isinstance(wcs_url, str):
         raise TypeError('URL must be of type string')
@@ -771,6 +853,18 @@ def load_as_file(url: str,
 
     """
 
+    # Trying to import owslib but returning error if owslib is not installed
+    try:
+        import owslib
+        from owslib import util
+        from owslib.wms import WebMapService
+        from owslib.wfs import WebFeatureService
+        from owslib.wcs import WebCoverageService
+        __all__ = [util]
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'owslib package is not installed. Use pip install owslib to install the latest version')
+
     # Trying to import urllib but returning error if urllib is not installed
     try:
         import urllib
@@ -871,6 +965,18 @@ def load_as_files(wcs_url: str,
 
     """
 
+    # Trying to import owslib but returning error if owslib is not installed
+    try:
+        import owslib
+        from owslib import util
+        from owslib.wms import WebMapService
+        from owslib.wfs import WebFeatureService
+        from owslib.wcs import WebCoverageService
+        __all__ = [util]
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(
+            'owslib package is not installed. Use pip install owslib to install the latest version')
+
     # Trying to import tqdm but returning error if tqdm is not installed
     try:
         from tqdm import tqdm
